Index: webkit/glue/resource_loader_bridge.h |
diff --git a/webkit/glue/resource_loader_bridge.h b/webkit/glue/resource_loader_bridge.h |
index 6711039652ad869bb9584f6b524f2e50f963c0b1..409e28974b8b1121b7bd0525a76c23cfdfaecc79 100644 |
--- a/webkit/glue/resource_loader_bridge.h |
+++ b/webkit/glue/resource_loader_bridge.h |
@@ -52,8 +52,11 @@ struct ResourceLoadTimingInfo { |
ResourceLoadTimingInfo(); |
~ResourceLoadTimingInfo(); |
- // All the values in this struct are given as offsets in milliseconds wrt |
- // this base time. |
+ // All the values in this struct are given as offsets in ticks wrt |
+ // this base tick count. |
+ int64 base_ticks; |
+ |
+ // The value of Time::Now() when base_ticks was set. |
base::Time base_time; |
wtc
2011/08/26 21:55:41
It is strange that we can use base::Time here but
James Simonsen
2011/08/26 22:34:29
Indeed. And I'd even already done the IPC work. :/
|
// The time that proxy processing started. For requests with no proxy phase, |
@@ -324,9 +327,10 @@ class ResourceLoaderBridge { |
// Called when the response is complete. This method signals completion of |
// the resource load.ff |
- virtual void OnCompletedRequest(const net::URLRequestStatus& status, |
- const std::string& security_info, |
- const base::Time& completion_time) = 0; |
+ virtual void OnCompletedRequest( |
+ const net::URLRequestStatus& status, |
+ const std::string& security_info, |
+ const base::TimeTicks& completion_time) = 0; |
}; |
// use Create() for construction, but anybody can delete at any time, |